@@ -105,6 +105,7 @@ def raytrace_single(config, internal=False):
 
     # Setup the dispatchers.
     if 'filters' in config:
+        logging.debug("Creating filters")
         filters = Dispatcher(config, 'filters')
         filters.instantiate()
         filters.setup()
@@ -113,6 +114,7 @@ def raytrace_single(config, internal=False):
     else:
         filters = None
 
+    logging.debug("Creating sources")
     sources = Dispatcher(config, 'sources')
     sources.instantiate()
     sources.apply_filters(filters)
@@ -120,6 +122,7 @@ def raytrace_single(config, internal=False):
     sources.initialize()
     config['sources'] = sources.get_config()
 
+    logging.debug("Creating optics")
     optics = Dispatcher(config, 'optics')
     optics.instantiate()
     optics.setup()
@@ -163,7 +166,9 @@ def _raytrace_iter(config, sources, optics):
     keep_images  = config['general']['keep_images']
     keep_history = config['general']['keep_history']
 
+    logging.debug('Generating rays')
     rays = sources.generate_rays(keep_history=keep_history)
+    logging.debug('Raytracing optics')
     rays = optics.trace(rays, keep_history=keep_history, keep_images=keep_images)
 
     # Combine sources and optics outputs.
@@ -284,9 +289,12 @@ def combine_raytrace(input_list):
     # Combine the images.
     for key_opt in key_opt_list:
         if key_opt in input_list[0]['total']['image']:
-            output['total']['image'][key_opt] = np.zeros(input_list[0]['total']['image'][key_opt].shape)
-            for ii_iter in range(num_iter):
-                output['total']['image'][key_opt] += input_list[ii_iter]['total']['image'][key_opt]
+            if input_list[0]['total']['image'][key_opt] is not None:
+                output['total']['image'][key_opt] = np.zeros(input_list[0]['total']['image'][key_opt].shape)
+                for ii_iter in range(num_iter):
+                    output['total']['image'][key_opt] += input_list[ii_iter]['total']['image'][key_opt]
+            else:
+                output['total']['image'][key_opt] = None
 
     # Combine all the histories.
     if len(input_list[0]['found']['history']) > 0:
@@ -377,15 +385,16 @@ def save_images(results):
 
     for key_opt in results['config']['optics']:
         if key_opt in results['total']['image']:
-            filename = '_'.join(filter(None, (prefix, key_opt, suffix, run_suffix)))+ext
-            filepath = os.path.join(results['config']['general']['output_path'], filename)
-            
-            image_temp = results['total']['image'][key_opt]
-            if rotate:
-                image_temp = np.rot90(image_temp)
-            
-            generated_image = Image.fromarray(image_temp)
-            generated_image.save(filepath)
-            
-            logging.info('Saved image: {}'.format(filepath))
+            if results['total']['image'][key_opt] is not None:
+                filename = '_'.join(filter(None, (prefix, key_opt, suffix, run_suffix)))+ext
+                filepath = os.path.join(results['config']['general']['output_path'], filename)
+
+                image_temp = results['total']['image'][key_opt]
+                if rotate:
+                    image_temp = np.rot90(image_temp)
+
+                generated_image = Image.fromarray(image_temp)
+                generated_image.save(filepath)
+
+                logging.info('Saved image: {}'.format(filepath))
         
